@@ -79,8 +79,9 @@ class Page():
         return content
 
     def get_page_content(self):
-        print self.content
-        return self.content["data"]
+        if "data" in self.content:
+            return self.content["data"]
+        return None
 
     def get_page_content_from_list(self):
         content = self.file_contents
